# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: distlock.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='distlock.proto',
  package='distlock',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x64istlock.proto\x12\x08\x64istlock\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xa3\x01\n\x04Lock\x12\x11\n\tglobal_id\x18\x01 \x01(\t\x12-\n\nexpires_in\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0e\x61\x63quired_since\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0flast_owner_name\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\"E\n\x12\x41\x63quireLockRequest\x12\x1c\n\x04lock\x18\x01 \x01(\x0b\x32\x0e.distlock.Lock\x12\x11\n\toverwrite\x18\x02 \x01(\x08\"\x8f\x01\n\x13\x41\x63quireLockResponse\x12%\n\racquired_lock\x18\x01 \x01(\x0b\x32\x0e.distlock.Lock\x12%\n\rexisting_lock\x18\x02 \x01(\x0b\x32\x0e.distlock.Lock\x12*\n\x07\x65lapsed\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\"`\n\x12\x41\x63quireManyRequest\x12.\n\x08requests\x18\x01 \x03(\x0b\x32\x1c.distlock.AcquireLockRequest\x12\x1a\n\x12max_acquired_locks\x18\x02 \x01(\r\"G\n\x13\x41\x63quireManyResponse\x12\x30\n\tresponses\x18\x01 \x03(\x0b\x32\x1d.distlock.AcquireLockResponse\"P\n\x12ReleaseLockRequest\x12\x1c\n\x04lock\x18\x01 \x01(\x0b\x32\x0e.distlock.Lock\x12\x1c\n\x14return_released_lock\x18\x02 \x01(\x08\"h\n\x13ReleaseLockResponse\x12%\n\rreleased_lock\x18\x01 \x01(\x0b\x32\x0e.distlock.Lock\x12*\n\x07\x65lapsed\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\"\xdd\x02\n\nAnyRequest\x12<\n\x14\x61\x63quire_lock_request\x18\x01 \x01(\x0b\x32\x1c.distlock.AcquireLockRequestH\x00\x12<\n\x14\x61\x63quire_many_request\x18\x02 \x01(\x0b\x32\x1c.distlock.AcquireManyRequestH\x00\x12<\n\x14release_lock_request\x18\x03 \x01(\x0b\x32\x1c.distlock.ReleaseLockRequestH\x00\x12P\n\x1fget_current_server_time_request\x18\x04 \x01(\x0b\x32%.distlock.GetCurrentServerTimeRequestH\x00\x12\x38\n\x12list_locks_request\x18\x05 \x01(\x0b\x32\x1a.distlock.ListLocksRequestH\x00\x42\t\n\x07request\"\xe9\x02\n\x0b\x41nyResponse\x12>\n\x15\x61\x63quire_lock_response\x18\x01 \x01(\x0b\x32\x1d.distlock.AcquireLockResponseH\x00\x12>\n\x15\x61\x63quire_many_response\x18\x02 \x01(\x0b\x32\x1d.distlock.AcquireManyResponseH\x00\x12>\n\x15release_lock_response\x18\x03 \x01(\x0b\x32\x1d.distlock.ReleaseLockResponseH\x00\x12R\n get_current_server_time_response\x18\x04 \x01(\x0b\x32&.distlock.GetCurrentServerTimeResponseH\x00\x12:\n\x13list_locks_response\x18\x05 \x01(\x0b\x32\x1b.distlock.ListLocksResponseH\x00\x42\n\n\x08response\"\x1d\n\x1bGetCurrentServerTimeRequest\"O\n\x1cGetCurrentServerTimeResponse\x12/\n\x0bserver_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"V\n\x13ProcessBatchRequest\x12&\n\x08requests\x18\x01 \x03(\x0b\x32\x14.distlock.AnyRequest\x12\x17\n\x0fis_synchronized\x18\x02 \x01(\x08\"l\n\x14ProcessBatchResponse\x12(\n\tresponses\x18\x01 \x03(\x0b\x32\x15.distlock.AnyResponse\x12*\n\x07\x65lapsed\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\"B\n\x13LockMatchExpression\x12\x17\n\x0fglobal_id_regex\x18\x01 \x01(\t\x12\x12\n\nis_expired\x18\x02 \x01(\x08\"\x98\x01\n\x10ListLocksRequest\x12\x11\n\tstart_key\x18\x01 \x01(\t\x12\x0f\n\x07\x65nd_key\x18\x02 \x01(\t\x12/\n\x08includes\x18\x03 \x03(\x0b\x32\x1d.distlock.LockMatchExpression\x12/\n\x08\x65xcludes\x18\x04 \x03(\x0b\x32\x1d.distlock.LockMatchExpression\"^\n\x11ListLocksResponse\x12\x1d\n\x05locks\x18\x01 \x03(\x0b\x32\x0e.distlock.Lock\x12*\n\x07\x65lapsed\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\"7\n\x11\x43ountLocksRequest\x12\x11\n\tstart_key\x18\x01 \x01(\t\x12\x0f\n\x07\x65nd_key\x18\x02 \x01(\t\"{\n\x12\x43ountLocksResponse\x12\x0f\n\x07\x65xpired\x18\x01 \x01(\x04\x12\x11\n\tunexpired\x18\x02 \x01(\x04\x12\x15\n\rno_expiration\x18\x03 \x01(\x04\x12*\n\x07\x65lapsed\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration2\xbd\x04\n\x12LockManagerService\x12J\n\x0b\x41\x63quireLock\x12\x1c.distlock.AcquireLockRequest\x1a\x1d.distlock.AcquireLockResponse\x12J\n\x0b\x41\x63quireMany\x12\x1c.distlock.AcquireManyRequest\x1a\x1d.distlock.AcquireManyResponse\x12J\n\x0bReleaseLock\x12\x1c.distlock.ReleaseLockRequest\x1a\x1d.distlock.ReleaseLockResponse\x12M\n\x0cProcessBatch\x12\x1d.distlock.ProcessBatchRequest\x1a\x1e.distlock.ProcessBatchResponse\x12\x44\n\tListLocks\x12\x1a.distlock.ListLocksRequest\x1a\x1b.distlock.ListLocksResponse\x12G\n\nCountLocks\x12\x1b.distlock.CountLocksRequest\x1a\x1c.distlock.CountLocksResponse\x12\x65\n\x14GetCurrentServerTime\x12%.distlock.GetCurrentServerTimeRequest\x1a&.distlock.GetCurrentServerTimeResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_LOCK = _descriptor.Descriptor(
  name='Lock',
  full_name='distlock.Lock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='global_id', full_name='distlock.Lock.global_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='distlock.Lock.expires_in', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquired_since', full_name='distlock.Lock.acquired_since', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_owner_name', full_name='distlock.Lock.last_owner_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='distlock.Lock.data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=257,
)


_ACQUIRELOCKREQUEST = _descriptor.Descriptor(
  name='AcquireLockRequest',
  full_name='distlock.AcquireLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock', full_name='distlock.AcquireLockRequest.lock', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='distlock.AcquireLockRequest.overwrite', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=328,
)


_ACQUIRELOCKRESPONSE = _descriptor.Descriptor(
  name='AcquireLockResponse',
  full_name='distlock.AcquireLockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acquired_lock', full_name='distlock.AcquireLockResponse.acquired_lock', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='existing_lock', full_name='distlock.AcquireLockResponse.existing_lock', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elapsed', full_name='distlock.AcquireLockResponse.elapsed', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=474,
)


_ACQUIREMANYREQUEST = _descriptor.Descriptor(
  name='AcquireManyRequest',
  full_name='distlock.AcquireManyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='distlock.AcquireManyRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_acquired_locks', full_name='distlock.AcquireManyRequest.max_acquired_locks', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=572,
)


_ACQUIREMANYRESPONSE = _descriptor.Descriptor(
  name='AcquireManyResponse',
  full_name='distlock.AcquireManyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='distlock.AcquireManyResponse.responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=645,
)


_RELEASELOCKREQUEST = _descriptor.Descriptor(
  name='ReleaseLockRequest',
  full_name='distlock.ReleaseLockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lock', full_name='distlock.ReleaseLockRequest.lock', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_released_lock', full_name='distlock.ReleaseLockRequest.return_released_lock', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=727,
)


_RELEASELOCKRESPONSE = _descriptor.Descriptor(
  name='ReleaseLockResponse',
  full_name='distlock.ReleaseLockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='released_lock', full_name='distlock.ReleaseLockResponse.released_lock', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elapsed', full_name='distlock.ReleaseLockResponse.elapsed', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=833,
)


_ANYREQUEST = _descriptor.Descriptor(
  name='AnyRequest',
  full_name='distlock.AnyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acquire_lock_request', full_name='distlock.AnyRequest.acquire_lock_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquire_many_request', full_name='distlock.AnyRequest.acquire_many_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release_lock_request', full_name='distlock.AnyRequest.release_lock_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_current_server_time_request', full_name='distlock.AnyRequest.get_current_server_time_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_locks_request', full_name='distlock.AnyRequest.list_locks_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='distlock.AnyRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=836,
  serialized_end=1185,
)


_ANYRESPONSE = _descriptor.Descriptor(
  name='AnyResponse',
  full_name='distlock.AnyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acquire_lock_response', full_name='distlock.AnyResponse.acquire_lock_response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acquire_many_response', full_name='distlock.AnyResponse.acquire_many_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='release_lock_response', full_name='distlock.AnyResponse.release_lock_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_current_server_time_response', full_name='distlock.AnyResponse.get_current_server_time_response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_locks_response', full_name='distlock.AnyResponse.list_locks_response', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='distlock.AnyResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1188,
  serialized_end=1549,
)


_GETCURRENTSERVERTIMEREQUEST = _descriptor.Descriptor(
  name='GetCurrentServerTimeRequest',
  full_name='distlock.GetCurrentServerTimeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1551,
  serialized_end=1580,
)


_GETCURRENTSERVERTIMERESPONSE = _descriptor.Descriptor(
  name='GetCurrentServerTimeResponse',
  full_name='distlock.GetCurrentServerTimeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_time', full_name='distlock.GetCurrentServerTimeResponse.server_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1582,
  serialized_end=1661,
)


_PROCESSBATCHREQUEST = _descriptor.Descriptor(
  name='ProcessBatchRequest',
  full_name='distlock.ProcessBatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='distlock.ProcessBatchRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_synchronized', full_name='distlock.ProcessBatchRequest.is_synchronized', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1663,
  serialized_end=1749,
)


_PROCESSBATCHRESPONSE = _descriptor.Descriptor(
  name='ProcessBatchResponse',
  full_name='distlock.ProcessBatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='distlock.ProcessBatchResponse.responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elapsed', full_name='distlock.ProcessBatchResponse.elapsed', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1751,
  serialized_end=1859,
)


_LOCKMATCHEXPRESSION = _descriptor.Descriptor(
  name='LockMatchExpression',
  full_name='distlock.LockMatchExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='global_id_regex', full_name='distlock.LockMatchExpression.global_id_regex', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_expired', full_name='distlock.LockMatchExpression.is_expired', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1861,
  serialized_end=1927,
)


_LISTLOCKSREQUEST = _descriptor.Descriptor(
  name='ListLocksRequest',
  full_name='distlock.ListLocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_key', full_name='distlock.ListLocksRequest.start_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_key', full_name='distlock.ListLocksRequest.end_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includes', full_name='distlock.ListLocksRequest.includes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludes', full_name='distlock.ListLocksRequest.excludes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1930,
  serialized_end=2082,
)


_LISTLOCKSRESPONSE = _descriptor.Descriptor(
  name='ListLocksResponse',
  full_name='distlock.ListLocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locks', full_name='distlock.ListLocksResponse.locks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elapsed', full_name='distlock.ListLocksResponse.elapsed', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2084,
  serialized_end=2178,
)


_COUNTLOCKSREQUEST = _descriptor.Descriptor(
  name='CountLocksRequest',
  full_name='distlock.CountLocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_key', full_name='distlock.CountLocksRequest.start_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_key', full_name='distlock.CountLocksRequest.end_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2180,
  serialized_end=2235,
)


_COUNTLOCKSRESPONSE = _descriptor.Descriptor(
  name='CountLocksResponse',
  full_name='distlock.CountLocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='expired', full_name='distlock.CountLocksResponse.expired', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unexpired', full_name='distlock.CountLocksResponse.unexpired', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_expiration', full_name='distlock.CountLocksResponse.no_expiration', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elapsed', full_name='distlock.CountLocksResponse.elapsed', index=3,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2237,
  serialized_end=2360,
)

_LOCK.fields_by_name['expires_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LOCK.fields_by_name['acquired_since'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACQUIRELOCKREQUEST.fields_by_name['lock'].message_type = _LOCK
_ACQUIRELOCKRESPONSE.fields_by_name['acquired_lock'].message_type = _LOCK
_ACQUIRELOCKRESPONSE.fields_by_name['existing_lock'].message_type = _LOCK
_ACQUIRELOCKRESPONSE.fields_by_name['elapsed'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ACQUIREMANYREQUEST.fields_by_name['requests'].message_type = _ACQUIRELOCKREQUEST
_ACQUIREMANYRESPONSE.fields_by_name['responses'].message_type = _ACQUIRELOCKRESPONSE
_RELEASELOCKREQUEST.fields_by_name['lock'].message_type = _LOCK
_RELEASELOCKRESPONSE.fields_by_name['released_lock'].message_type = _LOCK
_RELEASELOCKRESPONSE.fields_by_name['elapsed'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ANYREQUEST.fields_by_name['acquire_lock_request'].message_type = _ACQUIRELOCKREQUEST
_ANYREQUEST.fields_by_name['acquire_many_request'].message_type = _ACQUIREMANYREQUEST
_ANYREQUEST.fields_by_name['release_lock_request'].message_type = _RELEASELOCKREQUEST
_ANYREQUEST.fields_by_name['get_current_server_time_request'].message_type = _GETCURRENTSERVERTIMEREQUEST
_ANYREQUEST.fields_by_name['list_locks_request'].message_type = _LISTLOCKSREQUEST
_ANYREQUEST.oneofs_by_name['request'].fields.append(
  _ANYREQUEST.fields_by_name['acquire_lock_request'])
_ANYREQUEST.fields_by_name['acquire_lock_request'].containing_oneof = _ANYREQUEST.oneofs_by_name['request']
_ANYREQUEST.oneofs_by_name['request'].fields.append(
  _ANYREQUEST.fields_by_name['acquire_many_request'])
_ANYREQUEST.fields_by_name['acquire_many_request'].containing_oneof = _ANYREQUEST.oneofs_by_name['request']
_ANYREQUEST.oneofs_by_name['request'].fields.append(
  _ANYREQUEST.fields_by_name['release_lock_request'])
_ANYREQUEST.fields_by_name['release_lock_request'].containing_oneof = _ANYREQUEST.oneofs_by_name['request']
_ANYREQUEST.oneofs_by_name['request'].fields.append(
  _ANYREQUEST.fields_by_name['get_current_server_time_request'])
_ANYREQUEST.fields_by_name['get_current_server_time_request'].containing_oneof = _ANYREQUEST.oneofs_by_name['request']
_ANYREQUEST.oneofs_by_name['request'].fields.append(
  _ANYREQUEST.fields_by_name['list_locks_request'])
_ANYREQUEST.fields_by_name['list_locks_request'].containing_oneof = _ANYREQUEST.oneofs_by_name['request']
_ANYRESPONSE.fields_by_name['acquire_lock_response'].message_type = _ACQUIRELOCKRESPONSE
_ANYRESPONSE.fields_by_name['acquire_many_response'].message_type = _ACQUIREMANYRESPONSE
_ANYRESPONSE.fields_by_name['release_lock_response'].message_type = _RELEASELOCKRESPONSE
_ANYRESPONSE.fields_by_name['get_current_server_time_response'].message_type = _GETCURRENTSERVERTIMERESPONSE
_ANYRESPONSE.fields_by_name['list_locks_response'].message_type = _LISTLOCKSRESPONSE
_ANYRESPONSE.oneofs_by_name['response'].fields.append(
  _ANYRESPONSE.fields_by_name['acquire_lock_response'])
_ANYRESPONSE.fields_by_name['acquire_lock_response'].containing_oneof = _ANYRESPONSE.oneofs_by_name['response']
_ANYRESPONSE.oneofs_by_name['response'].fields.append(
  _ANYRESPONSE.fields_by_name['acquire_many_response'])
_ANYRESPONSE.fields_by_name['acquire_many_response'].containing_oneof = _ANYRESPONSE.oneofs_by_name['response']
_ANYRESPONSE.oneofs_by_name['response'].fields.append(
  _ANYRESPONSE.fields_by_name['release_lock_response'])
_ANYRESPONSE.fields_by_name['release_lock_response'].containing_oneof = _ANYRESPONSE.oneofs_by_name['response']
_ANYRESPONSE.oneofs_by_name['response'].fields.append(
  _ANYRESPONSE.fields_by_name['get_current_server_time_response'])
_ANYRESPONSE.fields_by_name['get_current_server_time_response'].containing_oneof = _ANYRESPONSE.oneofs_by_name['response']
_ANYRESPONSE.oneofs_by_name['response'].fields.append(
  _ANYRESPONSE.fields_by_name['list_locks_response'])
_ANYRESPONSE.fields_by_name['list_locks_response'].containing_oneof = _ANYRESPONSE.oneofs_by_name['response']
_GETCURRENTSERVERTIMERESPONSE.fields_by_name['server_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROCESSBATCHREQUEST.fields_by_name['requests'].message_type = _ANYREQUEST
_PROCESSBATCHRESPONSE.fields_by_name['responses'].message_type = _ANYRESPONSE
_PROCESSBATCHRESPONSE.fields_by_name['elapsed'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_LISTLOCKSREQUEST.fields_by_name['includes'].message_type = _LOCKMATCHEXPRESSION
_LISTLOCKSREQUEST.fields_by_name['excludes'].message_type = _LOCKMATCHEXPRESSION
_LISTLOCKSRESPONSE.fields_by_name['locks'].message_type = _LOCK
_LISTLOCKSRESPONSE.fields_by_name['elapsed'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COUNTLOCKSRESPONSE.fields_by_name['elapsed'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['Lock'] = _LOCK
DESCRIPTOR.message_types_by_name['AcquireLockRequest'] = _ACQUIRELOCKREQUEST
DESCRIPTOR.message_types_by_name['AcquireLockResponse'] = _ACQUIRELOCKRESPONSE
DESCRIPTOR.message_types_by_name['AcquireManyRequest'] = _ACQUIREMANYREQUEST
DESCRIPTOR.message_types_by_name['AcquireManyResponse'] = _ACQUIREMANYRESPONSE
DESCRIPTOR.message_types_by_name['ReleaseLockRequest'] = _RELEASELOCKREQUEST
DESCRIPTOR.message_types_by_name['ReleaseLockResponse'] = _RELEASELOCKRESPONSE
DESCRIPTOR.message_types_by_name['AnyRequest'] = _ANYREQUEST
DESCRIPTOR.message_types_by_name['AnyResponse'] = _ANYRESPONSE
DESCRIPTOR.message_types_by_name['GetCurrentServerTimeRequest'] = _GETCURRENTSERVERTIMEREQUEST
DESCRIPTOR.message_types_by_name['GetCurrentServerTimeResponse'] = _GETCURRENTSERVERTIMERESPONSE
DESCRIPTOR.message_types_by_name['ProcessBatchRequest'] = _PROCESSBATCHREQUEST
DESCRIPTOR.message_types_by_name['ProcessBatchResponse'] = _PROCESSBATCHRESPONSE
DESCRIPTOR.message_types_by_name['LockMatchExpression'] = _LOCKMATCHEXPRESSION
DESCRIPTOR.message_types_by_name['ListLocksRequest'] = _LISTLOCKSREQUEST
DESCRIPTOR.message_types_by_name['ListLocksResponse'] = _LISTLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['CountLocksRequest'] = _COUNTLOCKSREQUEST
DESCRIPTOR.message_types_by_name['CountLocksResponse'] = _COUNTLOCKSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Lock = _reflection.GeneratedProtocolMessageType('Lock', (_message.Message,), {
  'DESCRIPTOR' : _LOCK,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.Lock)
  })
_sym_db.RegisterMessage(Lock)

AcquireLockRequest = _reflection.GeneratedProtocolMessageType('AcquireLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIRELOCKREQUEST,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.AcquireLockRequest)
  })
_sym_db.RegisterMessage(AcquireLockRequest)

AcquireLockResponse = _reflection.GeneratedProtocolMessageType('AcquireLockResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIRELOCKRESPONSE,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.AcquireLockResponse)
  })
_sym_db.RegisterMessage(AcquireLockResponse)

AcquireManyRequest = _reflection.GeneratedProtocolMessageType('AcquireManyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIREMANYREQUEST,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.AcquireManyRequest)
  })
_sym_db.RegisterMessage(AcquireManyRequest)

AcquireManyResponse = _reflection.GeneratedProtocolMessageType('AcquireManyResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACQUIREMANYRESPONSE,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.AcquireManyResponse)
  })
_sym_db.RegisterMessage(AcquireManyResponse)

ReleaseLockRequest = _reflection.GeneratedProtocolMessageType('ReleaseLockRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELEASELOCKREQUEST,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.ReleaseLockRequest)
  })
_sym_db.RegisterMessage(ReleaseLockRequest)

ReleaseLockResponse = _reflection.GeneratedProtocolMessageType('ReleaseLockResponse', (_message.Message,), {
  'DESCRIPTOR' : _RELEASELOCKRESPONSE,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.ReleaseLockResponse)
  })
_sym_db.RegisterMessage(ReleaseLockResponse)

AnyRequest = _reflection.GeneratedProtocolMessageType('AnyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ANYREQUEST,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.AnyRequest)
  })
_sym_db.RegisterMessage(AnyRequest)

AnyResponse = _reflection.GeneratedProtocolMessageType('AnyResponse', (_message.Message,), {
  'DESCRIPTOR' : _ANYRESPONSE,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.AnyResponse)
  })
_sym_db.RegisterMessage(AnyResponse)

GetCurrentServerTimeRequest = _reflection.GeneratedProtocolMessageType('GetCurrentServerTimeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTSERVERTIMEREQUEST,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.GetCurrentServerTimeRequest)
  })
_sym_db.RegisterMessage(GetCurrentServerTimeRequest)

GetCurrentServerTimeResponse = _reflection.GeneratedProtocolMessageType('GetCurrentServerTimeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTSERVERTIMERESPONSE,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.GetCurrentServerTimeResponse)
  })
_sym_db.RegisterMessage(GetCurrentServerTimeResponse)

ProcessBatchRequest = _reflection.GeneratedProtocolMessageType('ProcessBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSBATCHREQUEST,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.ProcessBatchRequest)
  })
_sym_db.RegisterMessage(ProcessBatchRequest)

ProcessBatchResponse = _reflection.GeneratedProtocolMessageType('ProcessBatchResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSBATCHRESPONSE,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.ProcessBatchResponse)
  })
_sym_db.RegisterMessage(ProcessBatchResponse)

LockMatchExpression = _reflection.GeneratedProtocolMessageType('LockMatchExpression', (_message.Message,), {
  'DESCRIPTOR' : _LOCKMATCHEXPRESSION,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.LockMatchExpression)
  })
_sym_db.RegisterMessage(LockMatchExpression)

ListLocksRequest = _reflection.GeneratedProtocolMessageType('ListLocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOCKSREQUEST,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.ListLocksRequest)
  })
_sym_db.RegisterMessage(ListLocksRequest)

ListLocksResponse = _reflection.GeneratedProtocolMessageType('ListLocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOCKSRESPONSE,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.ListLocksResponse)
  })
_sym_db.RegisterMessage(ListLocksResponse)

CountLocksRequest = _reflection.GeneratedProtocolMessageType('CountLocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _COUNTLOCKSREQUEST,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.CountLocksRequest)
  })
_sym_db.RegisterMessage(CountLocksRequest)

CountLocksResponse = _reflection.GeneratedProtocolMessageType('CountLocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _COUNTLOCKSRESPONSE,
  '__module__' : 'distlock_pb2'
  # @@protoc_insertion_point(class_scope:distlock.CountLocksResponse)
  })
_sym_db.RegisterMessage(CountLocksResponse)



_LOCKMANAGERSERVICE = _descriptor.ServiceDescriptor(
  name='LockManagerService',
  full_name='distlock.LockManagerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2363,
  serialized_end=2936,
  methods=[
  _descriptor.MethodDescriptor(
    name='AcquireLock',
    full_name='distlock.LockManagerService.AcquireLock',
    index=0,
    containing_service=None,
    input_type=_ACQUIRELOCKREQUEST,
    output_type=_ACQUIRELOCKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AcquireMany',
    full_name='distlock.LockManagerService.AcquireMany',
    index=1,
    containing_service=None,
    input_type=_ACQUIREMANYREQUEST,
    output_type=_ACQUIREMANYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReleaseLock',
    full_name='distlock.LockManagerService.ReleaseLock',
    index=2,
    containing_service=None,
    input_type=_RELEASELOCKREQUEST,
    output_type=_RELEASELOCKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ProcessBatch',
    full_name='distlock.LockManagerService.ProcessBatch',
    index=3,
    containing_service=None,
    input_type=_PROCESSBATCHREQUEST,
    output_type=_PROCESSBATCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLocks',
    full_name='distlock.LockManagerService.ListLocks',
    index=4,
    containing_service=None,
    input_type=_LISTLOCKSREQUEST,
    output_type=_LISTLOCKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CountLocks',
    full_name='distlock.LockManagerService.CountLocks',
    index=5,
    containing_service=None,
    input_type=_COUNTLOCKSREQUEST,
    output_type=_COUNTLOCKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCurrentServerTime',
    full_name='distlock.LockManagerService.GetCurrentServerTime',
    index=6,
    containing_service=None,
    input_type=_GETCURRENTSERVERTIMEREQUEST,
    output_type=_GETCURRENTSERVERTIMERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOCKMANAGERSERVICE)

DESCRIPTOR.services_by_name['LockManagerService'] = _LOCKMANAGERSERVICE

# @@protoc_insertion_point(module_scope)
